@@ -1,12 +1,18 @@
 # copyright (C) 1997-98 Jean-Luc Fontaine (mailto:jfontain@mygale.org)
 # this program is free software: please refer to the BSD type license enclosed in this package
 
-set rcsId {$Id: datagraf.tcl,v 1.26 1998/04/21 16:21:59 jfontain Exp $}
+set rcsId {$Id: datagraf.tcl,v 1.34 1998/05/01 15:16:21 jfontain Exp $}
 
 class dataGraph {
 
+if {$::officialBLT} {
+    set (widget) stripchart
+} else {
+    set (widget) graph
+}
+
     proc dataGraph {this parentPath args} composite {
-        [new graph $parentPath -title {} -topmargin 3 -bufferelements 0 -plotborderwidth 1] $args
+        [new $dataGraph::(widget) $parentPath -title {} -topmargin 3 -bufferelements 0 -plotborderwidth 1] $args
     } blt2DViewer {$widget::($this,path)} {
         $widget::($this,path) xaxis configure -tickfont $font::(smallNormal) -title {} -rotate 90 -command dataGraph::axisTime
         composite::complete $this
@@ -35,7 +41,7 @@ class dataGraph {
     }
 
     proc options {this} {
-        # force size values
+        # force size and interval values
         return [list\
             [list -height height Height 200]\
             [list -interval interval Interval 5]\
@@ -49,7 +55,18 @@ class dataGraph {
     }
 
     proc set-interval {this value} {
+        set range [expr {$composite::($this,-samples)*$value}]
+        set size [expr {$range/10}]                                                   ;# do not display more than 10 major divisions
+        # choose among predefined discrete values
+        foreach step {60 300 600 1800 3600 18000 36000 86400} division {6 5 5 5 6 5 5 4} {
+            if {$step>$size} break
+        }
+        $widget::($this,path) xaxis configure -stepsize $step -subdivisions $division
+if {$::officialBLT} {
+        $widget::($this,path) xaxis configure -range $range -shiftby $value
+} else {
         xAxisUpdate $this [clock seconds]
+}
     }
 
     proc set-samples {this value} {                                                                     ;# stored at composite level
@@ -58,56 +75,67 @@ class dataGraph {
         }
     }
 
-    proc xAxisUpdate {this currentTime} { ;### calculate steps sizes according to interval ###
+if {!$::officialBLT} {
+    proc xAxisUpdate {this currentTime} {
         $widget::($this,path) xaxis configure\
-            -min [expr {$currentTime-($composite::($this,-samples)*$composite::($this,-interval))}] -max $currentTime\
-            -stepsize 60 -subdivisions 6
+            -min [expr {$currentTime-($composite::($this,-samples)*$composite::($this,-interval))}] -max $currentTime
     }
+}
 
     proc axisTime {path value} {
-        return [clock format $value -format %T]
+        return [clock format $value -format %H:%M]                                    ;# do not show seconds as they are always zero
     }
 
     proc newElement {this path args} {                                                          ;# invoked from 2D viewer base class
         return [eval new element $path $args]
     }
 
+if {!$::officialBLT} {
     proc updateTimeDisplay {this seconds} {
         xAxisUpdate $this $seconds
     }
+}
 
     proc updateElement {this element seconds value} {
         element::update $element $seconds $value
     }
+
 }
 
 class dataGraph {
     class element {
 
-        set (intervals) 100                                                                       ;### should be parameterizable ###
+if {$::officialBLT} {
+        set (scope) variable
+} else {
+        set (scope) global                           ;# prevents BLT internal error report on exit with at least one graph displayed
+}
 
         proc element {this path args} switched {$args} {
-            $path element line $this -label {}                                        ;# use object identifier as element identifier
+            [set (scope)] ${this}xData
+            [set (scope)] ${this}yData
 
-            ### axis data vectors (should be a namespace variable when blt is fixed) ###
-            global [set xVector ${this}xData] [set yVector ${this}yData]
-            global $xVector  ;### should be a variable but it causes a "called Tcl_FindHashEntry on deleted table" error on exit ###
-            set dots [expr {[set (intervals)]+1}]
-            blt::vector ${xVector}($dots)
-            $path element configure $this -xdata $xVector
+            $path element create $this -label {} -symbol none                         ;# use object identifier as element identifier
 
-            set yVector ${this}yData                                                                           ;# y axis data vector
-            global $yVector
-            blt::vector ${yVector}($dots)
-            $path element configure $this -ydata $yVector
+            set dots [expr {$configuration::(graphNumberOfIntervals)+1}]
+if {$::officialBLT} {
+            blt::vector -variable ${this}xData ${this}xData($dots)                                             ;# x axis data vector
+            blt::vector -variable ${this}yData ${this}yData($dots)                                             ;# y axis data vector
+} else {
+            blt::vector ${this}xData($dots)
+            blt::vector ${this}yData($dots)
+}
+            $path element configure $this -xdata ${this}xData -ydata ${this}yData
 
             set ($this,path) $path
             switched::complete $this
         }
 
         proc ~element {this} {
-            global [set xVector ${this}xData] [set yVector ${this}yData]
-            unset $xVector $yVector
+            [set (scope)] ${this}xData
+            [set (scope)] ${this}yData
+
+            unset ${this}xData ${this}yData
             [set ($this,path)] element delete $this
             if {[string length $switched::($this,-deletecommand)]>0} {
                 uplevel #0 $switched::($this,-deletecommand)                                ;# always invoke command at global level
@@ -129,15 +157,16 @@ class dataGraph {
         proc set-deletecommand {this value} {}                                                   ;# data is stored at switched level
 
         proc update {this x y} {
-            global [set xVector ${this}xData] [set yVector ${this}yData]
+            [set (scope)] ${this}xData
+            [set (scope)] ${this}yData
 
             if {[string length $y]==0} {
                 set y 0                                                              ;# too bad BLT graph cannot handle empty values
             }
-            $xVector delete 0
-            $xVector append $x
-            $yVector delete 0                                                         ;# achieve scrolling by deleting first element
-            $yVector append $y                                                                            ;# and appending new value
+            ${this}xData delete 0                                                     ;# achieve scrolling by deleting first element
+            ${this}yData delete 0
+            ${this}xData append $x                                                                        ;# and appending new value
+            ${this}yData append $y
         }
     }
 }
