@@ -1,15 +1,29 @@
 # copyright (C) 1997-98 Jean-Luc Fontaine (mailto:jfontain@mygale.org)
 # this program is free software: please refer to the BSD type license enclosed in this package
 
-set rcsId {$Id: html.tcl,v 1.5 1998/04/21 16:33:50 jfontain Exp $}
+set rcsId {$Id: html.tcl,v 1.11 1998/04/30 17:35:30 jfontain Exp $}
 
-# use a font nicer than the HTML library default one
+# use bold and smaller sizes than the HTML library default ones for headers
 array set HMtag_map {
-    code {family Helvetica}
-    kbd {family Helvetica weight bold}
-    pre {fill 0 family Helvetica Tnowrap nowrap}
-    samp {family Helvetica}
-    tt {family Helvetica}
+    h1 {size 22 weight bold}
+    h2 {size 20 weight bold}
+    h3 {size 18 weight bold}
+    h4 {size 16 weight bold}
+    h5 {size 14 weight bold}
+    h6 {weight bold}
+}
+
+# use a font (Helvetica instead of Times) nicer and smaller than the HTML library default one
+set HMtag_map(hmstart) {
+    family Helvetica  weight medium  style r  size 12
+    Tcenter ""  Tlink ""  Tnowrap ""  Tunderline ""  list list
+    fill 1  indent ""  counter 0  adjust 0
+}
+
+# make headers and preformatted text stand out better by adding new lines around them.
+array set HMinsert_map {
+    h1 "\n\n" /h1 "\n\n" h2 "\n\n" /h2 "\n\n" h3 "\n\n" /h3 "\n\n" h4 "\n\n" /h4 "\n\n" h5 "\n\n" /h5 "\n\n" h6 "\n\n" /h6 "\n\n"
+    pre "\n\n" /pre "\n\n"
 }
 
 proc helpWindow {} {
@@ -27,10 +41,10 @@ proc helpWindow {} {
     set panes [new panner .topHelp -panes 2]                                         ;# split window in 2 for contents and help data
     pack $widget::($panes,path) -fill both -expand 1
 
-    set contents [new scroll text $panner::($panes,frame1)]
+    set contents [new scroll text $panner::($panes,frame1) -horizontal 0]
     pack $widget::($contents,path) -fill both -expand 1
 
-    set widget [new scroll text $panner::($panes,frame2)]
+    set widget [new scroll text $panner::($panes,frame2) -horizontal 0]
     pack $widget::($widget,path) -fill both -expand 1
 
     bind .topHelp.bound <Destroy> "delete $widget $contents $panes"
