@@ -1,68 +1,68 @@
 set htmlHelpContents {
 <UL>
 <LI>
-<A HREF="#about">About this document</A></LI>
+<A HREF="#about">1. About this document</A></LI>
 
 <LI>
-<A HREF="#introduction">Introduction</A></LI>
+<A HREF="#introduction">2. Introduction</A></LI>
 
 <LI>
-<A HREF="#required">Required software</A></LI>
+<A HREF="#required">3. Required software</A></LI>
 
 <LI>
-<A HREF="#architecture">Architecture</A></LI>
+<A HREF="#architecture">4. Architecture</A></LI>
 
 <LI>
-<A HREF="#core">Core</A></LI>
+<A HREF="#core">5. Core</A></LI>
 
 <UL>
 <LI>
-<A HREF="#userinterface">User interface</A></LI>
+<A HREF="#userinterface">5.1. User interface</A></LI>
 
 <UL>
 <LI>
-<A HREF="#draganddrop">drag and drop</A></LI>
+<A HREF="#draganddrop">5.1.1. drag and drop</A></LI>
 
 <UL>
 <LI>
-<A HREF="#dropsites">drop sites</A></LI>
+<A HREF="#dropsites">5.1.1.1. drop sites</A></LI>
 
 <LI>
-<A HREF="#dragsites">drag sites</A></LI>
+<A HREF="#dragsites">5.1.1.2. drag sites</A></LI>
 </UL>
 </UL>
 
 <LI>
-<A HREF="#commandline">Command line</A></LI>
+<A HREF="#commandline">5.2. Command line</A></LI>
 </UL>
 
 <LI>
-<A HREF="#modules">Modules</A></LI>
+<A HREF="#modules">6. Modules</A></LI>
 
 <UL>
 <LI>
-<A HREF="#source">source</A></LI>
+<A HREF="#source">6.1. source</A></LI>
 
 <UL>
 <LI>
-<A HREF="#namespace">namespace</A></LI>
+<A HREF="#namespace">6.1.1. namespace</A></LI>
 
 <LI>
-<A HREF="#configuration">configuration</A></LI>
+<A HREF="#configuration">6.1.2. configuration</A></LI>
 
 <LI>
-<A HREF="#variabledata">variable data</A></LI>
+<A HREF="#variabledata">6.1.3. variable data</A></LI>
 </UL>
 
 <LI>
-<A HREF="#installation">installation</A></LI>
+<A HREF="#installation">6.2. installation</A></LI>
 </UL>
 
 <LI>
-<A HREF="#future">Future developments</A></LI>
+<A HREF="#future">7. Future developments</A></LI>
 
 <LI>
-<A HREF="#misc">Miscellaneous information</A></LI>
+<A HREF="#misc">8. Miscellaneous information</A></LI>
 </UL>
 </BODY>
 </HTML>
@@ -71,12 +71,12 @@ set htmlHelpData {
 <BODY>
 <HTML>
 <H3>
-<A NAME="about"></A>About this document</H3>
+<A NAME="about"></A>1. About this document</H3>
 This document contains general information, reference information and examples
 designed to help the user understand the moodss application and the programmer
 write modules for it.
 <H3>
-<A NAME="introduction"></A>Introduction</H3>
+<A NAME="introduction"></A>2. Introduction</H3>
 Quite often, one needs to monitor changing data, whether it might come
 from a system, such as the different processes running on a Unix server,
 or from a network, such as the kind and volume of traffic that runs through
@@ -117,8 +117,14 @@ be written in plain Tcl and optionally use dynamically linked libraries
 written in the C language (modules are packages in the Tcl sense).
 
 <P>Modules are loaded when moodss is started. One or more modules can be
-handled concurrently (new feature of version 3.0). Module names are specified
-in the command line and cannot be unloaded.
+handled concurrently (new feature of versions 3.x). This way, you may monitor
+data coming from any number of heterogeneous sources. Module names are
+specified in the command line and cannot be unloaded.
+
+<P>Since module data access is entirely customizable (through C code, Tcl,
+HTTP, ...) and since several modules can be loaded at once, applications
+for moodss become limitless. For example, comparing a remote database server
+CPU load and a network load from a probe on the same graph becomes possible.
 
 <P>As features are added to moodss, different ways of viewing data will
 be made available while the modules will stay the same. The goal of moodss
@@ -140,8 +146,8 @@ in.
 the terms of a BSD type license: please see the COPYRIGHT file or use the
 main window About help menu for more information.
 <H3>
-<A NAME="required"></A>Required software</H3>
-For the current version (3.0), the following packages must be installed
+<A NAME="required"></A>3. Required software</H3>
+For the current version (3.3), the following packages must be installed
 before attempting to install moodss (make sure to check the INSTALL file
 for the latest information):
 <UL>
@@ -149,10 +155,11 @@ for the latest information):
 Tcl/Tk version 8.0 or above (at <A HREF="http://sunscript.sun.com/">http://sunscript.sun.com/</A>)</LI>
 
 <LI>
-tkTable version 1.8 or above (at <A HREF="http://www.cs.uoregon.edu/research/tcl/">http://www.cs.uoregon.edu/research/tcl/</A>)<B>*</B></LI>
+tkTable version 2.0 or above (at <A HREF="ftp://ftp.cs.uoregon.edu/pub/tcl/tkTable/">ftp://ftp.cs.uoregon.edu/pub/tcl/tkTable/</A>)<B>*</B></LI>
 
 <LI>
-the BLT library for Tcl/Tk 8.0 (<A HREF="ftp://ftp.neosoft.com/pub/tcl/sorted/devel/blt8.0p2-unoff">ftp://ftp.neosoft.com/pub/tcl/sorted/devel/blt8.0p2-unoff.tgz</A>)<B>*</B></LI>
+the BLT library for Tcl/Tk 8.0/8.1 (<A HREF="ftp://ftp.neosoft.com/pub/tcl/sorted/devel/blt8.0-unoff.tgz">ftp://ftp.neosoft.com/pub/tcl/sorted/devel/blt8.0-unoff.tgz</A>
+or <A HREF="ftp://ftp.neosoft.com/pub/tcl/sorted/devel/blt2.3-8.1.tgz">ftp://ftp.neosoft.com/pub/tcl/sorted/devel/blt2.3-8.1.tar.gz</A>)<B>*</B></LI>
 </UL>
 
 <DIV ALIGN=right><B>*</B><I> many thanks to the authors for these great
@@ -172,11 +179,11 @@ stooop version 3.5.1 or above (at <A HREF="http://www.mygale.org/~jfontain/">htt
 scwoop version 2.2 or above (at <A HREF="http://www.mygale.org/~jfontain/">http://www.mygale.org/~jfontain/</A>)</LI>
 
 <LI>
-tkpiechart version 4.2 or above (at <A HREF="http://www.mygale.org/~jfontain/">http://www.mygale.org/~jfontain/</A>)</LI>
+tkpiechart version 4.3 or above (at <A HREF="http://www.mygale.org/~jfontain/">http://www.mygale.org/~jfontain/</A>)</LI>
 </UL>
 
 <H3>
-<A NAME="architecture"></A>Architecture</H3>
+<A NAME="architecture"></A>4. Architecture</H3>
 The moodss application is composed of the core software and one or several
 modules. Modules are implemented as Tcl packages and thus usually comprise
 a Tcl source file and a pkgIndex.tcl file required by the Tcl package implementation.
@@ -201,22 +208,22 @@ when dropped into the graphical viewer, result in the creation of corresponding
 data graph lines, bars, or slices.
 
 <P>Any draggable data can be dropped in valid drop sites at any time. It
-is thus possible to drag several data cells from any viewer into other
-ones, the trash, ... even if the data comes from different modules.
+is thus possible to drag several data cells from any table or any viewer
+into other ones, the trash, ... even if the data comes from different modules.
 
 <P>All data viewers can be moved and resized at will through a simple internal
 window manager.
 <H3>
-<A NAME="core"></A>Core</H3>
+<A NAME="core"></A>5. Core</H3>
 
 <H4>
-<A NAME="userinterface"></A>User interface</H4>
+<A NAME="userinterface"></A>5.1. User interface</H4>
 Soon after the application launch, tabular data is displayed in one or
 more tkTable widgets with automatic scroll bars, between the menu bar,
 the drop sites with graphical viewers and trash icons and a message area,
 as one can see below:
 <BR>&nbsp;
-<CENTER><IMG SRC="moodss1.jpg" ALT="moodss initial main window view" HEIGHT=506 WIDTH=620></CENTER>
+<CENTER><IMG SRC="moodss1.jpg" ALT="moodss initial main window view" HEIGHT=451 WIDTH=541></CENTER>
 
 
 <P>The message area is used to display status information, such as when
@@ -234,7 +241,7 @@ to gracefully quit the moodss application.
 <P>The <I>Options</I> menu contains the <I>Poll time</I> entry which when
 selected launches the corresponding dialog box, as shown below:
 <BR>&nbsp;
-<CENTER><IMG SRC="moodss2.jpg" ALT="poll time dialog box" HEIGHT=225 WIDTH=228></CENTER>
+<CENTER><IMG SRC="moodss2.jpg" ALT="poll time dialog box" HEIGHT=238 WIDTH=226></CENTER>
 
 
 <P>The user can select a new poll time among the module choices from a
@@ -242,14 +249,24 @@ spin entry widget, or directly type in a new value, as long as it is not
 smaller than the module minimum poll time, in which case a message dialog
 box warns the user.
 
+<P>When several modules are used, the minimum poll time is the greater
+of the minimum poll times of all modules. The default poll time (used when
+moodss is started) is the greater of the default poll times of all modules.
+The available choices in the poll time dialog box is the combination of
+all modules poll times.
+
 <P>Table data can be sorted at any time by simply clicking on a column
 title. Clicking on the same column title again sorts the data in opposite
 order, thus toggling between increasing and decreasing orders.
 <BR>When sorting, the selected column is used as a reference, meaning that
 all rows will be rearranged so that the selected column appears sorted,
 with values either increasing or decreasing.
-<BR>The reference column for sorting always appear in a darker shade of
-gray.
+<BR>A little arrow indicator is placed to the right of the reference column
+title label, pointing up or down depending on whether the sorting order
+is decreasing or increasing.
+<BR>Table columns can be interactively resized by holding the first mouse
+button down on a column border. The mouse cursor is changed to an horizontal
+double arrow on column borders to show this capability.
 
 <P>Aside from the main tables, graphical viewers can be created for viewing
 table cell data behavior over time. Viewers can also be deleted, data views
@@ -266,7 +283,7 @@ work with Tcl, please let me know so I can integrate them. Many thanks
 in advance...</I>
 <CENTER>
 <H5>
-<IMG SRC="moodss3.jpg" ALT="moodss window with graph data viewers" HEIGHT=656 WIDTH=682></H5></CENTER>
+<IMG SRC="moodss3.jpg" ALT="moodss window with graph data viewers" HEIGHT=650 WIDTH=583></H5></CENTER>
 All data viewers can be moved and resized thanks to handling areas in the
 data viewer borders. When moving the mouse pointer over these areas, the
 mouse cursor changes to indicate the available action. Corner handles allow
@@ -280,19 +297,20 @@ functionality is useless, as it behaves like a standard window manager
 (let me know if it does not).
 
 <P>The <I>Help</I> menu contains <I>Global</I> help (actually launches
-an embedded HTML viewer with this very document), <I>Modules</I> help,
-and <I>About</I> general information entries.
+an embedded HTML viewer with this very document), <I>Modules</I> help which
+displays all the loaded modules help texts, and <I>About</I> general information
+entries.
 <H5>
-<A NAME="draganddrop"></A>Drag and drop</H5>
+<A NAME="draganddrop"></A>5.1.1 Drag and drop</H5>
 Drag and drop in moodss tries to behave as the familiar Windows functionality
 (no, it doesn't mean I am a Bill Gates fan :). For example, to create a
-cell graphical plot, one must place the mouse pointer over a data cell
-in the main table, hold down the first mouse button (the left one for a
-right handed user) while dragging over to the left-most icon below the
-menu bar (when dragging an object, as the mouse pointer passes over possible
-drop sites, they are highlighted with a thin black surrounding border for
-user feedback). Releasing the mouse button at this time results in the
-creation of a BLT graph viewer.
+graphical plot, one must first select one or more data cells in a data
+table, hold down the first mouse button (the left one for a right handed
+user) while dragging over to the left-most icon below the menu bar (when
+dragging an object, as the mouse pointer passes over possible drop sites,
+they are highlighted with a thin black surrounding border for user feedback).
+Releasing the mouse button at this time results in the creation of a BLT
+graph viewer.
 
 <P>Only valid drop sites for the data being dragged are highlighted when
 the mouse cursor passes over them, thus guaranteeing error free operations.
@@ -300,7 +318,7 @@ the mouse cursor passes over them, thus guaranteeing error free operations.
 <P>In summary, data cells can be dragged from any data table or any viewer
 into any viewer icon, any viewer or the trash can.
 <H6>
-<A NAME="dropsites"></A>Drop sites</H6>
+<A NAME="dropsites"></A>5.1.1.1. Drop sites</H6>
 All icons right below the menu bar are valid drop sites for data cells
 (several may be dropped at the same time). From left to right:
 <UL>
@@ -344,29 +362,34 @@ button result in the corresponding viewer elements to be destroyed. If
 there are no remaining lines, the graphical viewer itself (graph, bar chart
 or pie) is destroyed.
 <H6>
-<A NAME="dragsites"></A>Drag sites</H6>
-A data table is obviously a drag site. At the moment, only one cell can
-be dragged at once.
+<A NAME="dragsites"></A>5.1.1.2. Drag sites</H6>
+A data table is obviously a drag site. One or more cells can be dragged
+at once after selection, using the traditional single / shift / control
+mouse click techniques.
 
 <P>Any graphical viewer is also a drag site. It requires selecting one
 or more graphical viewer elements before initiating the drag operation
 from any point in the viewer. If there are no selected elements, dragging
 is impossible: the mouse cursor is not changed into the drag circular cursor.
+If there are no elements, then the viewer itself can be dragged and dropped
+into the trash only.
 <H4>
-<A NAME="commandline"></A>Command line</H4>
+<A NAME="commandline"></A>5.2. Command line</H4>
 Launching moodss is very simple: just pass one or more data module names
 as parameters, as in:
 <PRE>$ wish moodss random</PRE>
 or, for 2 modules at once:
 <PRE>$ wish moodss ps cpustats</PRE>
-You may eventually specify a poll time in seconds using:
+You may not specify the same module more than once in the command line.
+
+<P>You may eventually specify a poll time in seconds using:
 <PRE>$ wish moodss -update 25 random</PRE>
 
 <H3>
-<A NAME="modules"></A>Modules</H3>
+<A NAME="modules"></A>6. Modules</H3>
 All examples are drawn from the <I>random</I> sample module.
 <H4>
-<A NAME="source"></A>source</H4>
+<A NAME="source"></A>6.1. source</H4>
 Since a module is a package, it must have a name in the Tcl sense. For
 example, at the beginning of the <I>random.tcl</I> file, one can find the
 following statement:
@@ -375,7 +398,7 @@ This line simply states that this is the <I>1.1</I> version of the <I>random</I>
 package. Please note that the package name must also be used as the module
 namespace name (see below).
 <H5>
-<A NAME="namespace"></A>namespace</H5>
+<A NAME="namespace"></A>6.1.1. namespace</H5>
 All module procedures and data are kept in a specific namespace bearing
 the module name. For example (from the <I>random.tcl</I> source file):
 <PRE>namespace eval random {
@@ -388,7 +411,7 @@ the module name. For example (from the <I>random.tcl</I> source file):
 }</PRE>
 
 <H5>
-<A NAME="configuration"></A>configuration</H5>
+<A NAME="configuration"></A>6.1.2. configuration</H5>
 The module configuration defines the data table column headers, help information,
 ... This data never changes during the lifetime of the application.
 
@@ -463,7 +486,7 @@ index column values for the cell.
 when the user requests help information on the current module from within
 the help menu.
 <H5>
-<A NAME="variabledata"></A>variable data</H5>
+<A NAME="variabledata"></A>6.1.3. variable data</H5>
 The tabular data (variable data) that the module code must update is stored
 in the same <I>data</I> array as the module configuration data.
 
@@ -526,7 +549,7 @@ a row that has disappeared cannot be reused. Row numbers need not be consecutive
 updated, the <I>updates</I> member array must be incremented so that the
 core knows that it can update the table data display.
 <H4>
-<A NAME="installation"></A>installation</H4>
+<A NAME="installation"></A>6.2. installation</H4>
 A module is a package in the Tcl sense. When writing a module, you must
 then provide a <I>pkgIndex.tcl</I> file along with the module code file.
 The <I>pkgIndex.tcl</I> file is very simple, as the following example shows:
@@ -543,13 +566,13 @@ The current directory (.) is appended to the <I>auto_load</I> global list
 variable so that sample modules can be found when moodss is run from the
 unpacking directory.
 
-<P>For example, if you unpacked moodss in <I>/home/joe/moodss-3.0/</I>,
-you will find the random module package in <I>/home/joe/moodss-3.0/random/</I>
+<P>For example, if you unpacked moodss in <I>/home/joe/moodss-3.3/</I>,
+you will find the random module package in <I>/home/joe/moodss-3.3/random/</I>
 so that the following will work:
-<PRE>$ cd /home/joe/moodss-3.0/
+<PRE>$ cd /home/joe/moodss-3.3/
 $ wish moodss random</PRE>
 You can install your new modules in the default location: <I>/usr/local/lib/</I>
-on Unix. For example, if you move the files in <I>/home/joe/moodss-3.0/random/</I>
+on Unix. For example, if you move the files in <I>/home/joe/moodss-3.3/random/</I>
 to <I>/usr/local/lib/random/</I>, moodss (actually Tcl :) will still be
 able to find the <I>random</I> module (again, look at the <I>pkg_mkIndex</I>
 manual page for more information).
@@ -557,7 +580,7 @@ manual page for more information).
 <P>Please take a look at the INSTALL file for the latest information on
 how to install the moodss application itself.
 <H3>
-<A NAME="future"></A>Future developments</H3>
+<A NAME="future"></A>7. Future developments</H3>
 The following features will eventually be added to the core:
 <UL>
 <LI>
@@ -578,7 +601,7 @@ writable table cells?</LI>
 I welcome any suggestion for new features that you may need in your specific
 use of moodss.
 <H3>
-<A NAME="misc"></A>Miscellaneous information</H3>
+<A NAME="misc"></A>8. Miscellaneous information</H3>
 For downloading Tcl software (such as stooop, scwoop, ...), visit my <A HREF="http://www.mygale.org/~jfontain/">web
 page</A>.
 
