@@ -1,7 +1,7 @@
 # copyright (C) 1997-98 Jean-Luc Fontaine (mailto:jfontain@mygale.org)
 # this program is free software: please refer to the BSD type license enclosed in this package
 
-set rcsId {$Id: viewer.tcl,v 1.5 1998/04/21 16:17:33 jfontain Exp $}
+set rcsId {$Id: viewer.tcl,v 1.7 1998/04/30 20:54:34 jfontain Exp $}
 
 class viewer {                                                                             ;# handle viewers related functionalities
     # viewers do not derive from a common interface class but rather support a common set a options through the composite class
@@ -9,9 +9,7 @@ class viewer {
     set viewer::(list) {}
 
     proc viewer {this} {
-        global canvas
-
-        new canvasHandles $canvas -path $widget::($this,path)                                         ;# manage new viewer in canvas
+        new canvasHandles $::canvas -path $widget::($this,path)                                       ;# manage new viewer in canvas
         lappend viewer::(list) $this
     }
 
@@ -30,14 +28,16 @@ class viewer {
     proc view {this cells} {                                                                  ;# cells is a list of data array cells
         foreach cell [parseCells $this $cells] {
             eval monitorCell $this $cell
+            set arrays([lindex $cell 0]) {}                                                                        ;# remember array
+        }
+        foreach array [array names arrays] {                                        ;# update viewer with current values immediately
+            update $this $array
         }
     }
 
     virtual proc monitorCell {this array row column}
 
     proc parseCells {this cells} {
-        global messenger
-
         if {[llength $cells]==0} return
         set parsed {}
         foreach cell $cells {
@@ -46,7 +46,7 @@ class viewer {
             }
             parse $cell array row column type
             if {[lsearch -exact [supportedTypes $this] $type]<0} {
-                lifoLabel::flash $messenger "cannot display data of type $type"
+                lifoLabel::flash $::messenger "cannot display data of type $type"
                 bell
                 return
             }
